@@ -16,10 +16,10 @@ class InitialiseDomainModel(InitialiseDomainModel):
         self.removePermission('Update', 'Result')
         self.removePermission('Update', 'Image')
         # Create objects.
-        now = datetime.datetime.now()
-        self.thisYear = now.year
-        self.thisMonth = now.month
-        self.thisDay = now.day
+        #now = datetime.datetime.now()
+        self.thisYear = 2011
+        self.thisMonth = 1
+        self.thisDay = 1
         self.createSymbols()
         self.createMarkets()
         self.createPriceProcesses()
@@ -47,6 +47,7 @@ class InitialiseDomainModel(InitialiseDomainModel):
         self.registry.protectionObjects.create('PriceProcess')
         self.registry.protectionObjects.create('ContractType')
         self.registry.protectionObjects.create('Pricer')
+        self.registry.protectionObjects.create('PricerPreference')
         self.registry.protectionObjects.create('Book')
         self.registry.protectionObjects.create('Model')
         self.registry.protectionObjects.create('Image')
@@ -154,13 +155,17 @@ class InitialiseDomainModel(InitialiseDomainModel):
             codeModuleName='quant.pricer.simple',
             codeClassName='AmericanBinomialTree'
         )
-        self.pricerEuropeanMontecarlo = self.registry.pricers.create(
+        self.pricerEuropeanMonteCarlo = self.registry.pricers.create(
             codeModuleName='quant.pricer.simple',
-            codeClassName='EuropeanMontecarlo'
+            codeClassName='EuropeanMonteCarlo'
         )
-        self.pricerAmericanMontecarlo = self.registry.pricers.create(
+        self.pricerAmericanMonteCarlo = self.registry.pricers.create(
             codeModuleName='quant.pricer.simple',
-            codeClassName='AmericanMontecarlo'
+            codeClassName='AmericanMonteCarlo'
+        )
+        self.pricerDslMonteCarlo = self.registry.pricers.create(
+            codeModuleName='quant.pricer.simple',
+            codeClassName='DslMonteCarlo'
         )
 
     def createPricerPreferences(self):
@@ -184,6 +189,16 @@ class InitialiseDomainModel(InitialiseDomainModel):
             contractType = self.contractTypeAmerican,
             pricer = self.pricerAmericanBinomialTree,
         )
+        self.registry.pricerPreferences.create(
+            priceProcess = self.priceProcessBlackScholes,
+            contractType = self.contractTypeDsl,
+            pricer = self.pricerDslMonteCarlo,
+        )
+        self.registry.pricerPreferences.create(
+            priceProcess = self.priceProcessLocalVolatility,
+            contractType = self.contractTypeDsl,
+            pricer = self.pricerDslMonteCarlo,
+        )
 
     def createImages(self):
         self.image1 = self.registry.images.create(observationTime=datetime.datetime(self.thisYear, self.thisMonth, self.thisDay), priceProcess=self.priceProcessBlackScholes)
