@@ -72,6 +72,8 @@ class LoginView(AuthenticateView):
             params = self.request.POST.copy()
             returnPath = params.get('returnPath', '')
             if returnPath:
+                if not returnPath.startswith('/'):
+                    returnPath = '/' + returnPath
                 self.returnPath = returnPath
             if self.session:
                 if returnPath:
