@@ -138,16 +138,8 @@ class CodesView(WelcomeView):
     minorNavigationItem = '/codes/'
 
     def setMinorNavigationItems(self):
-        self.minorNavigation = []
-        self.minorNavigation.append({
-            'title': 'Price processes', 'url': '/priceProcesses/'
-        })
-        self.minorNavigation.append({
-            'title': 'Contract types', 'url': '/contractTypes/'
-        })
-        self.minorNavigation.append({
-            'title': 'Pricers', 'url': '/pricers/'
-        })
+        from quant.django.apps.eui.views.registry import CodesNavigation
+        self.minorNavigation = CodesNavigation(self).createMinorItems()
 
 
 def welcome(request):
