@@ -17,7 +17,7 @@ class TestResult(TestCase):
     observationTime = datetime.datetime(thisYear, thisMonth, thisDay)
 
     def setUp(self):
-        self.image = self.registry.images.read(observationTime=self.observationTime)
+        self.image = self.registry.images.findDomainObjects()[-1]
         self.book = self.registry.books.read(title='My Book')
         self.result = self.registry.results.create(book=self.book, image=self.image)
 
