@@ -1,7 +1,7 @@
 import unittest
 from quant.pricer.basetest import PricerTestCase
-from quant.pricer.binomialtree import EuropeanBinomialTreePricer
-from quant.pricer.binomialtree import AmericanBinomialTreePricer
+from quant.pricer.simple import EuropeanBinomialTree
+from quant.pricer.simple import AmericanBinomialTree
 
 def suite():
     suites = [
@@ -13,14 +13,14 @@ def suite():
     return unittest.TestSuite(suites)
 
 
-class BinomialTreePricerTestCase(PricerTestCase):
+class BinomialTreeTestCase(PricerTestCase):
 
     DECIMALS = 3
 
 
-class TestEuropeanCall(BinomialTreePricerTestCase):
+class TestEuropeanCall(BinomialTreeTestCase):
 
-    pricerClass = EuropeanBinomialTreePricer
+    pricerClass = EuropeanBinomialTree
 
     strikePrice = 9
     lastPrice = 10
@@ -28,9 +28,9 @@ class TestEuropeanCall(BinomialTreePricerTestCase):
     expectedValue = 2.416
 
 
-class TestEuropeanPut(BinomialTreePricerTestCase):
+class TestEuropeanPut(BinomialTreeTestCase):
 
-    pricerClass = EuropeanBinomialTreePricer
+    pricerClass = EuropeanBinomialTree
     isPut = True
 
     strikePrice = 9
@@ -39,9 +39,9 @@ class TestEuropeanPut(BinomialTreePricerTestCase):
     expectedValue = 1.416
 
 
-class TestAmericanCall(BinomialTreePricerTestCase):
+class TestAmericanCall(BinomialTreeTestCase):
 
-    pricerClass = AmericanBinomialTreePricer
+    pricerClass = AmericanBinomialTree
 
     strikePrice = 9
     lastPrice = 10
@@ -49,9 +49,9 @@ class TestAmericanCall(BinomialTreePricerTestCase):
     expectedValue = 2.416
 
 
-class TestAmericanPut(BinomialTreePricerTestCase):
+class TestAmericanPut(BinomialTreeTestCase):
 
-    pricerClass = AmericanBinomialTreePricer
+    pricerClass = AmericanBinomialTree
     isPut = True
 
     strikePrice = 9
