@@ -1,15 +1,17 @@
 import unittest
 import quant.markettest
-import quant.pricer.test
 import quant.domtest
+import quant.priceprocess.test
+import quant.contracttype.test
+import quant.pricer.test
 
 def suite():
     suites = [
         quant.markettest.suite(),
-        quant.pricer.test.suite(),
         quant.domtest.suite(),
-#        quant.plugintest.suite(),
-#        quant.djangotest.suite(),
+        quant.priceprocess.test.suite(),
+        quant.contracttype.test.suite(),
+        quant.pricer.test.suite(),
     ]
     return unittest.TestSuite(suites)
 
